@@ -1399,6 +1399,7 @@ def pack_obj(obj, topic=None, envelope=('<KK-ENV>', '</KK-ENV>'), classes=()):
     """
     for cross-language rpc only, so no need for an unpack()
     pickle is already good enough for local transmission.
+    classes must be fully qualified class object, not from importlib.import_module()
     """
     if not topic:
         topic = type(obj).__name__
@@ -1448,7 +1449,7 @@ def safe_import_module(modname, path=None, prepend=True, reload=False):
         try:
             del sys.modules[modname]
         except KeyError as e:
-            glogger.error(f'reload module failed: {e}')
+            glogger.debug(f'reload module failed: {e}')
     mod = importlib.import_module(modname)
     if path:
         lazy_remove_from_sys_path([path])
@@ -1519,30 +1520,23 @@ def flatten_nested_lists(mylist):
 
 def show_results(succeeded, detail, advice, dryrun=False):
     banner = '** DRYRUN **' if dryrun else '*** SUCCEEDED ***' if succeeded else '* FAILED *'
-    advice_title = '' if not advice else 'Next:' if succeeded else 'Advice:'
-    detail_block = f'\n{detail}\n' if detail and advice else f'\n{detail}' if detail else ''
-    if detail and advice:
-        report = f"""
+    detail_title = 'Detail:'
+    detail_block = detail if detail else '- (N/A)'
+    advice_title = 'Next:' if succeeded else 'Advice:'
+    advice_block = advice if advice else '- (N/A)'
+    report = f"""
 {banner}
+
+{detail_title}
 {detail_block}
+
 {advice_title}
-{advice}"""
-    elif detail:
-        report = f"""
-{banner}
-{detail_block}"""
-    elif advice:
-        report = f"""
-{banner}
-{advice_title}
-{advice}"""
-    else:
-        report = f"""
-{banner}"""
+{advice_block}"""
     print(report)
+    return report
 
 
-def init_repo(srcfile, appdepth=2, repodepth=3, organization='mycompany', verbose=False, uselocale=False):
+def init_repo(srcfile, appdepth=2, repodepth=3, organization='mycompany', logname=None, verbose=False, uselocale=False):
     """
     assuming a project has a folder structure, create structure and facilities around it
     - structure example: app > subs (src, test, temp, locale, ...), where app is app root
@@ -1562,7 +1556,7 @@ def init_repo(srcfile, appdepth=2, repodepth=3, organization='mycompany', verbos
     common.locDir, common.srcDir, common.tmpDir, common.testDir = get_child_dirs(app_root := common.ancestorDirs[appdepth - 1], subs=('locale', 'src', 'temp', 'test'))
     common.pubTmpDir = osp.join(get_platform_tmp_dir(), organization, osp.basename(app_root))
     common.stem = osp.splitext(osp.basename(srcfile))[0]
-    common.logger = build_default_logger(common.tmpDir, name=common.stem, verbose=verbose)
+    common.logger = build_default_logger(common.tmpDir, name=logname if logname else common.stem, verbose=verbose)
     if uselocale:
         common.translator = init_translator(common.locDir)
     return common
@@ -2035,6 +2029,25 @@ def lazy_load_listfile(single_or_listfile: str, ext='.list'):
     return [single_item]
 
 
+def is_link(path):
+    """
+    on windows
+    - osp.islink(path) always returns False
+    - os.readlink(path) throws when link itself does not exist
+    - osp.isdir(path) / osp.exists(path) returns True only when linked source is an existing dir
+    on mac
+    - osp.islink(path) returns True when link exists
+    - osp.isdir(path) / osp.exists(path) returns True only when linked source is an existing dir
+    """
+    if platform.system() == 'Windows':
+        try:
+            lnk = os.readlink(path)
+            return True
+        except FileNotFoundError:
+            return False
+    return osp.islink(path)
+
+
 def _test():
     pass
 
